import * as solid_js from 'solid-js';
import { Component, JSXElement, JSX } from 'solid-js';
import * as atomic_router from 'atomic-router';
import { RouteParams, RouteInstance, RouteQuery, createHistoryRouter } from 'atomic-router';
import * as history from 'history';
import * as effector from 'effector';

interface RouteViewConfig<Props, Params extends RouteParams> {
    route: RouteInstance<Params> | RouteInstance<Params>[];
    view: Component<Props>;
    otherwise?: Component<Props>;
}
declare function createRouteView<Props, Params extends RouteParams, Config extends {
    [key in keyof RouteViewConfig<Props, Params>]?: RouteViewConfig<Props, Params>[key];
}>(config: Config): (props: Props & Omit<RouteViewConfig<Props, Params>, keyof Config>) => solid_js.JSX.Element;

interface RouteRecord<Props, Params extends RouteParams> {
    route: RouteInstance<Params> | RouteInstance<Params>[];
    view: Component<Props>;
    layout?: Component<{
        children: JSXElement;
    }>;
}
interface RoutesViewConfig {
    routes: RouteRecord<any, any>[];
    otherwise?: Component<any>;
}
declare function createRoutesView<Config extends RoutesViewConfig>(config: Config): (props: Omit<Config, keyof Config>) => solid_js.JSX.Element;

type LinkProps<Params extends RouteParams> = {
    to: RouteInstance<Params> | string;
    params?: Params;
    query?: RouteQuery;
    activeClass?: string;
    inactiveClass?: string;
} & Exclude<JSX.AnchorHTMLAttributes<HTMLAnchorElement>, 'href'>;
declare function Link<Params extends RouteParams>(props: LinkProps<Params>): JSX.Element;

type RouteProps<Params extends RouteParams> = {
    route: RouteInstance<Params> | RouteInstance<Params>[];
    view: Component;
};
declare function Route<Params extends RouteParams>(props: RouteProps<Params>): solid_js.JSX.Element;

type Router = ReturnType<typeof createHistoryRouter>;
declare const RouterContext: solid_js.Context<{
    $path: effector.StoreWritable<string>;
    $activeRoutes: effector.StoreWritable<atomic_router.RouteInstance<any>[]>;
    $history: effector.StoreWritable<history.History>;
    setHistory: effector.EventCallable<history.History>;
    $query: effector.StoreWritable<atomic_router.RouteQuery>;
    back: effector.EventCallable<void>;
    forward: effector.EventCallable<void>;
    push: effector.Effect<Omit<atomic_router.HistoryPushParams, "history">, atomic_router.HistoryPushParams, Error>;
    routes: atomic_router.RouteObject<any>[];
    initialized: effector.EventCallable<{
        activeRoutes: atomic_router.RouteInstance<any>[];
        path: string;
        query: atomic_router.RouteQuery;
    }>;
    routeNotFound: effector.EventCallable<void>;
} | null>;
declare function RouterProvider(props: {
    router: Router;
    children: JSX.Element;
}): JSX.Element;
declare function useRouter(): {
    $path: effector.StoreWritable<string>;
    $activeRoutes: effector.StoreWritable<atomic_router.RouteInstance<any>[]>;
    $history: effector.StoreWritable<history.History>;
    setHistory: effector.EventCallable<history.History>;
    $query: effector.StoreWritable<atomic_router.RouteQuery>;
    back: effector.EventCallable<void>;
    forward: effector.EventCallable<void>;
    push: effector.Effect<Omit<atomic_router.HistoryPushParams, "history">, atomic_router.HistoryPushParams, Error>;
    routes: atomic_router.RouteObject<any>[];
    initialized: effector.EventCallable<{
        activeRoutes: atomic_router.RouteInstance<any>[];
        path: string;
        query: atomic_router.RouteQuery;
    }>;
    routeNotFound: effector.EventCallable<void>;
};

export { Link, LinkProps, Route, RouteViewConfig, RouterContext, RouterProvider, RoutesViewConfig, createRouteView, createRoutesView, useRouter };
